#
# spec file for package q4wine
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           q4wine
Version:        1.1+r2
Release:        6.3
Summary:        Qt4 GUI for WINE
License:        GPL-3.0
Group:          System/Emulators/PC
Url:            http://q4wine.brezblock.org.ua/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-1.1-r2.tar.bz2
# PATCH-FIX-UPSTREAM q4wine-fix-documentation-url.patch boo#926859 tehnick-8@yandex.ru -- Fix documentation URL. Use web.archive.org until project website will be repaired. Also disable automatic opening this documentation after initial program configuring.
Patch0:         q4wine-fix-documentation-url.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  fuseiso
BuildRequires:  hicolor-icon-theme
BuildRequires:  icoutils
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtDBus)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(QtSql)
BuildRequires:  pkgconfig(QtXml)
Requires:       fuseiso
Requires:       icoutils
Requires:       libqt4-sql-sqlite
Requires:       sqlite3
Requires:       sudo
Requires:       wine
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Q4Wine is an Qt4-based GUI for WINE. It will help you to manage wine
prefixes and installed applications.

General features:
- Can export Qt color theme into wine colors settings.
- Can easy work with different wine versions at the same time.
- Easy creating, deleting and managing prefixes (WINEPREFIX).
- Easy controlling for wine process.
- Autostart icons support.
- Easy cd-image use.
- You can extract icons from PE files (.exe .dll).
- Easy backup and restore for managed prefixes.
- Wine AppDB browser.
- Logging subsystem.
- Winetricks support.

%lang_package

%prep
%setup -qn %{name}-1.1-r2
%patch0 -p1

%build
mkdir build
cd build
cmake .. \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_C_FLAGS="%{optflags}" \
    -DCMAKE_CXX_FLAGS="%{optflags}" \
    -DCMAKE_NO_BUILTIN_CHRPATH=ON
make %{?_smp_mflags} VERBOSE=1

%install
pushd build
%make_install
popd
%fdupes -s %{buildroot}%{_datadir}/
%find_lang %{name} --with-qt
%suse_update_desktop_file %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING README TODO
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/i18n/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_libdir}/%{name}/
%doc %{_mandir}/man?/*

%files lang -f %{name}.lang
%defattr(-,root,root,-)
%dir %{_datadir}/%{name}/i18n/

%changelog
* Mon Apr 13 2015 lazy.kent@opensuse.org
- Add q4wine-fix-documentation-url.patch: Fix documentation URL.
  Use web.archive.org until project website will be repaired. Also
  disable automatic opening this documentation after initial
  program configuring. (boo#926859)
* Fri Dec 20 2013 lazy.kent@opensuse.org
- Update to 1.1+r2.
  * Fixed error while loading application settings by key:
    'WineLibs'.
* Sun Dec  1 2013 lazy.kent@opensuse.org
- Update to 1.1+r1.
  * Fixed error while loading application settings by key:
    'WineLibs'.
  * Updated Afrikaans translation.
  * Fixed cmake warnings.
  * Updated .desktop file.
* Sun Nov 10 2013 lazy.kent@opensuse.org
- Update to 1.1.
  * Added:
    + Extended list of a virtual desktop resolutions.
    + Configure multiple wine paths globally to allow easily
    selection in prefixes.
    + Create predefined execution template strings for optirun,
    separate X display, e.t.c.
  * Fixed a few bugs.
* Tue Aug  6 2013 lazy.kent@opensuse.org
- Add "-DCMAKE_NO_BUILTIN_CHRPATH=ON" cmake option (fix build with
  updated cmake).
* Fri May  3 2013 lazy.kent@opensuse.org
- Update to 1.0+r3.
  * "Use single-click to run icons" does not affect icons in
    "setup" tab.
  * q4wine.desktop value "" for key "Path" in group "Desktop
    Entry".
  * Pre and Post run Icon scripts unusable, if the path contains
    ")".
* Sun Mar  3 2013 lazy.kent@opensuse.org
- Update to 1.0+r2.
  * Fixed:
    + Clean setup: error while loading application settings by key:
    prefixDefaultPath.
    + Winetricks plugin does not check script presence.
    + "Use single-click to run icons" does not affect icons in
    "setup" tab.
  * Added:
    + Winetricks plugin can use script installed in system.
    + Persian translation.
* Sun Jan 27 2013 lazy.kent@opensuse.org
- Update to 1.0+r1.
  * Fixed:
    + Prefix tree "Delete" menu item do not remove menu tree.
    + Support for utf8 system user name.
    + Winetricks doesn't work properly if WINEPATH contain spaces.
* Sun Jan 20 2013 lazy.kent@opensuse.org
- Update to 1.0.
  * Added:
    + Option to set default directory for new wine prefixes
    (default: $HOME/.local/share/wineprefixes).
    + q4wine desktop menu tree.
  * Removed:
    + File -> Install wizard menu entry.
  * Fixed:
    + Quote run string in case of console useage (gnome-terminal).
    + Winetricks functionality fails to work.
    + Cannot run 'Create Fake Drive' for a new prefix with a win32
    architecture.
    + System Language autodetection does not work.
    + Error while loading application settings by key: 'WineLibs'.
    File or path does not exist: "".
    + q4wine doesn't clean up user's tmp directory.
- Add fdupes to build dependencies; use %%fdupes macro.
* Wed Jun 27 2012 lazy.kent@opensuse.org
- Update to 0.999-rc8.
  * Added:
    + Prefix execution template string.
  * Fixed:
    + Regression: selection focus jumps to prefix name on
    subdirectory selection.
    + Regression: can't load user selected language.
* Sun Jun  3 2012 lazy.kent@opensuse.org
- Update to 0.999-rc7.
  * Added:
    + Winetricks database cache.
    + Merge Wintricks core.
    + New System Config interface.
    + Pre and Post run Icon scripts.
    + Icon and Prefix sorting (name, date).
    + Version string to About page.
    + Handler for wrong URL in wine app db.
    + Add Logging subsystem activation/deactivation button to
    Logging tab toolbar.
    + Add taskmgr, winemine, iexplorer, control, oleview icons to
    prefix's system folder.
    + New system icons from latest wine version.
    + Install program icons in $prefix/share/icons/hicolor/; Add
    16,22,32,48,64,96,128,256 icon sizes.
    + Add prefix to translation files names.
  * Fixed:
    + Enhanced win64 support for wine.
    + Better Wine library path autodetection.
    + Create ~/.local/share/wineprefixes directory if it does not
    exists.
    + Error is Desktop paths are empty.
    + Desktop Paths are wrongly labeled.
    + Unite Icon/Detail toolbar actions.
    + No translations autoupdate at project build. Use `make
    translations` instead.
    + Fixed process refresh loop.
    + Extended env command after console terminal.
    + Set WINEDEBUG to '-all' if logging subsystem disabled and
    program was executed not in console session.
    + Icon export dialog empty icons.
    + Dropped obsolete strings from translation files.
- Split off language package.
- Drop q4wine-gcc47.patch (fixed upstream).
- Add icon_theme_cache_post/un macros.
- BuildRequires: hicolor-icon-theme.
- Doesn't require fdupes.
* Sat Mar 24 2012 dimstar@opensuse.org
- Add q4wine-gcc47.patch: Fix build with gcc 4.7.
* Thu Nov 24 2011 lazy.kent@opensuse.org
- Corrected License tag according to SPDX Standard.
- Added desktop_database_post/un macros.
- Spec clean up.
* Sun Jun  5 2011 lazy.kent@opensuse.org
- Update to 0.121
  + Updated winetricks plugin
  + Option to make Prefix view unexpanded at startup
  + Polish translation
  + German translation
  + Hebrew translation
  + Extended virtual desktop resolution list
  + Prefix alphabetic sort
- Removed WITH_WINETRIKS option (it is default now)
- Use full URL for source
* Tue Apr  5 2011 lazy.kent@opensuse.org
- Requires libqt4-sql-sqlite
- Added LICENSE and TODO to docs
* Tue Dec 28 2010 lazy.kent@opensuse.org
- Update to 0.120+r1
  + q4wine now will create new symlinks when mounting
    $WINEPREFIX/dosdevices/${DRIVE}: pointing to the mount point
    and $WINEPREFIX/dosdevices/${DRIVE}:: pointing to the Image
    file
  + Prefixes list sorting
  + Fixed mount images in read only mode (ro)
  + Fixed removed media drive option in prefix settings dialog
  + English fixes
* Fri Oct  1 2010 lazy.kent.suse@gmail.com
- Added rpm build opt flags
* Fri Oct  1 2010 lazy.kent.suse@gmail.com
- Update to 0.120
  + Czech translation
  + Winetricks plugin updates
  + Added minimize to tray at startup option
  + Added minimize to tray at application icon startup option
  + Fixed some typo and GUI layouts
- Absolutely requires icoutils
* Sun Aug 22 2010 lazy.kent.suse@gmail.com
- Update to 0.119+r1
  + Updated Russian translation
  + Settings dialog online documentation
  + Fixed some of English spell errors
* Tue Aug 10 2010 lazy.kent.suse@gmail.com
- Update to 0.119
  + New Fake Drive settings dialog (Wizard now obsolete)
  + Added a lot of new Fake Drive options
  + Desktop integration
  + Updated Ukrainian, Italian and Spanish translations
  + Updated online documentation
  + Some fixes for GUI layout
  + Winetricks plugin improvement
  + Fixed some of English spellings
* Thu Apr 15 2010 lazy.kent.suse@gmail.com
- Update to 0.118
  + Added Wine AppDB support
  + Added helper binary and Application logger subsystem
  + You can mount iso images just by dropping them into q4wine
    icons list space
  + Automatic unmounting for mounted media before mount new one
  + Added man pages
  + A lot of fixes in Fake drive creation/update wizard
  + Fixed locale detection bugs
  + Fixes in tray icon support
  + Fixes in winetricks plugin
  + Fixed GUI issue with qtcurve theme engine
  + Fixed memory leaks
  + Fixed crush while drop existing icon
- Added fuseiso to BuildRequires
* Mon Nov 16 2009 lazy.kent.suse@gmail.com
- Update to 0.114r1
  + Fixed wrong wine C: drive symlink while create new Fake Drive
  + Fixed Russian spelling
  + Fixed some text layouts
* Sun Nov 15 2009 lazy.kent.suse@gmail.com
- Update to 0.114
  + New color option at Fake drive creation/update wizard
  + New wine settings in Fake drive creation/update wizard
  + New Spanish translation
  + New Italian translation
  + Fixed: prefix combobox change do not set right Prefix in Prefix
    tree view
  + Fix for prefix import and export
* Wed Oct 14 2009 lazy.kent.suse@gmail.com
- Corrected description
* Sun Oct  4 2009 lazy.kent.suse@gmail.com
- Update to 0.113
  + q4wine now remembers 8 recent mounted images
  + q4wine now remembers 8 recent launched binaries via Run dialog
  + Now q4wine save last user selected prefix and dir
  + Added q4wine-cli console utility for wine applications and
    prefixes management
  + Added translation file for Portuguese (Brazil)
  + Added http proxy support for winetricks
  + Added Drag & Drop support
  + Added Drag support q4wine icons export
  + Added Drop support for wine .exe and .com files
  + Added Drop support for wine .bat files
  + Added command line option for q4wine
  + Cleanup q4wine tmp directory on exit
  + Fixed GUI bug: Text fields size, on some desktop
    configurations, are too small to edit
- Added choice to build with/without icoutils support
- Added fuseiso to Requires
- Removed INSTALL from docs
- Corrected Summary
* Fri Jun 19 2009 lazy.kent.suse@gmail.com
- Change compiling outside of the source tree
* Sat May 16 2009 lazy.kent.suse@gmail.com
- Compilied with winetricks support
* Thu May 14 2009 lazy.kent.suse@gmail.com
- Desktop file updated
* Tue May  5 2009 lazy.kent.suse@gmail.com
- Updated to v0.112r1
  + Fixed compilation with Qt-4.4.X
